@@ -18,7 +18,7 @@ require_relative "../dll"
 require_relative "../logging"
 
 
-module SSU
+module Ssu
 
   class Saori < DLL::SAORI
 
@@ -83,7 +83,7 @@ module SSU
       @value = []
       result = method(@function[name][0]).call(args)
       if result != nil and not result.to_s.empty?
-        s = "SAORI/1.0 200 OK\r\nResult: " + result.to_s + "\r\n"
+        s = ("SAORI/1.0 200 OK\r\nResult: " + result.to_s + "\r\n")
         if not @value.empty?
           for i in 0..@value.length-1
             s = [s, "Value" + i.to_s + ": " + @value[i].to_s + "\r\n"].join("")
@@ -91,7 +91,7 @@ module SSU
         end
         s = [s, "Charset: " + charset.to_s + "\r\n"].join("")
         s = [s, "\r\n"].join("")
-        return s.encode(charset, :invalid => :replace, :undef => :replac)
+        return s.encode(charset, :invalid => :replace, :undef => :replace)
       else
         return RESPONSE[204]
       end
@@ -147,7 +147,7 @@ module SSU
       if args.length == 2
         end_ = s.length
       elsif args.length == 3 and ssu_is_digit([args[2]]) == 1
-        end_ = start + ssu_zen2han([args[2]]).to_i
+        end_ = (start + ssu_zen2han([args[2]]).to_i)
       else
         return ''
       end
@@ -206,17 +206,17 @@ module SSU
       end
       result = false
       if ['>', '＞'].include?(ope)
-        result = left > right
+        result = (left > right)
       elsif ['>=', '＞＝'].include?(ope)
-        result = left >= right
+        result = (left >= right)
       elsif ['<', '＜'].include?(ope)
-        result = left < right
+        result = (left < right)
       elsif ['<=', '＜＝'].include?(ope)
-        result = left <= right
+        result = (left <= right)
       elsif ['==', '＝＝'].include?(ope)
-        result = left == right
+        result = (left == right)
       elsif ['!=', '！＝'].include?(ope)
-        result = left != right
+        result = (left != right)
       else
         #pass # 'should not reach here'
       end
