@@ -147,7 +147,7 @@ module Menu
             }
       @__fontcolor = {
         'normal' => [0, 0, 0],
-        'prelight' => [255, 255, 255]
+        'hover' => [255, 255, 255]
       }
       @__imagepath = {
         'background' => nil,
@@ -207,7 +207,7 @@ module Menu
 
     def set_fontcolor(background, foreground)
       @__fontcolor['normal'] = background
-      @__fontcolor['prelight'] = foreground
+      @__fontcolor['hover'] = foreground
     end
 
     def set_pixmap(path_background, path_sidebar, path_foreground,
@@ -400,7 +400,7 @@ module Menu
         if name_list != nil and not name_list.empty? # visible
           for name in name_list
             visible = @parent.handle_request('GET', 'getstring', name)
-            if visible != nil
+            if visible != nil and not visible.empty?
               break
             end
           end
@@ -409,7 +409,7 @@ module Menu
           else
             __set_visible(key, true)
           end
-        else
+        elsif name_list == nil
           __set_visible(key, false)
         end
       end
@@ -427,7 +427,7 @@ module Menu
       if side > 1
         string = 'char' + side.to_s
       else
-        raise "assert" unless [0, 1].include?(side)
+        fail "assert" unless [0, 1].include?(side)
         string = ['sakura', 'kero'][side]
       end
       string = [string, '.popupmenu.visible'].join('')
@@ -445,7 +445,7 @@ module Menu
       if side > 1
         string = 'char' + side.to_s
       else
-        raise "assert" unless [0, 1].include?(side)
+        fail "assert" unless [0, 1].include?(side)
         string = ['sakura', 'kero'][side]
       end
       string = [string, '.recommendsites'].join('')
@@ -473,8 +473,8 @@ module Menu
     end
 
     def __set_caption(name, caption)
-      raise "assert" unless @__menu_list.include?(name)
-      raise "assert" unless caption.is_a?(String)
+      fail "assert" unless @__menu_list.include?(name)
+      fail "assert" unless caption.is_a?(String)
       item = @ui_manager.get_widget(['/popup/', name].join(''))
       if item != nil
         label = item.get_children()[0]
@@ -483,8 +483,8 @@ module Menu
     end
 
     def __set_visible(name, visible)
-      raise "assert" unless @__menu_list.include?(name)
-      raise "assert" unless [false, true].include?(visible)
+      fail "assert" unless @__menu_list.include?(name)
+      fail "assert" unless [false, true].include?(visible)
       @__menu_list[name]['visible'] = visible
     end
 
@@ -545,8 +545,9 @@ module Menu
                 end
                 if banner != nil
                   item.set_has_tooltip(true)
+                  pixbuf = Pix.create_pixbuf_from_file(banner, :is_pnr => false)
                   item.signal_connect('query-tooltip') do |widget, x, y, keyboard_mode, tooltip|
-                    next on_tooltip(widget, x, y, keyboard_mode, tooltip, banner)
+                    next on_tooltip(widget, x, y, keyboard_mode, tooltip, pixbuf)
                   end
                 else
                   item.set_has_tooltip(false)
@@ -626,8 +627,9 @@ module Menu
               end
               if banner != nil
                 item.set_has_tooltip(true)
+                pixbuf = Pix.create_pixbuf_from_file(banner, :is_pnr => false)
                 item.signal_connect('query-tooltip') do |widget, x, y, keyboardmode, tooltip|
-                  next on_tooltip(widget, x, y, keyboard_mode, tooltip, banner)
+                  next on_tooltip(widget, x, y, keyboard_mode, tooltip, pixbuf)
                 end
               else
                 item.set_has_tooltip(false)
@@ -678,8 +680,9 @@ module Menu
       end
       if thumbnail != nil
         item.set_has_tooltip(true)
+        pixbuf = Pix.create_pixbuf_from_file(thumbnail, :is_pnr => false)
         item.signal_connect('query-tooltip') do |widget, x, y, keyboard_mode, tooltip|
-          next on_tooltip(widget, x, y, keyboard_mode, tooltip, thumbnail)
+          next on_tooltip(widget, x, y, keyboard_mode, tooltip, pixbuf)
         end
       else
         item.set_has_tooltip(false)
@@ -693,7 +696,7 @@ module Menu
 
     def set_stylecontext(item, *args, provider: nil)
       _, offset_y = item.translate_coordinates(item.parent, 0, 0)
-      provider.load(data: ["GtkMenu {\n",
+      provider.load(data: ["menu {\n",
                            @__imagepath['background'],
                            "background-repeat: repeat-y;\n",
                            "color: ",
@@ -705,20 +708,20 @@ module Menu
                            ["background-position: ", @__align['background'], " ", (-offset_y).to_s, "px;\n"].join(''),
                            "}\n",
                            "\n",
-                           "GtkMenu :insensitive {\n",
+                           "menu :disabled {\n",
                            @__imagepath['background'],
                            "background-repeat: repeat-y;\n",
                            ["background-position: ", @__align['background'], " ", (-offset_y).to_s, "px;\n"].join(''),
                            "}\n",
                            "\n",
-                           "GtkMenu :prelight {\n",
+                           "menu :hover {\n",
                            @__imagepath['foreground'],
                            "background-repeat: repeat-y;\n",
                            "color: ",
                            "\#",
-                           sprintf("%02x", @__fontcolor['prelight'][0]),
-                           sprintf("%02x", @__fontcolor['prelight'][1]),
-                           sprintf("%02x", @__fontcolor['prelight'][2]),
+                           sprintf("%02x", @__fontcolor['hover'][0]),
+                           sprintf("%02x", @__fontcolor['hover'][1]),
+                           sprintf("%02x", @__fontcolor['hover'][2]),
                            ";\n",
                            ["background-position: ", @__align['foreground'], " ", (-offset_y).to_s, "px;\n"].join(''),
                            "}"
@@ -734,7 +737,7 @@ module Menu
         return false
       end
       _, offset_y = item.translate_coordinates(item.parent, 0, 0)
-      provider.load(data: ["GtkMenu {\n",
+      provider.load(data: ["menu {\n",
                            @__imagepath['background_with_sidebar'],
                            "background-repeat: repeat-y;\n",
                            "color: ",
@@ -748,7 +751,7 @@ module Menu
                            ["padding-left: ", @sidebar_width.to_s, "px;\n"].join(''),
                            "}\n",
                            "\n",
-                           "GtkMenu :insensitive {\n",
+                           "menu :disabled {\n",
                            @__imagepath['background_with_sidebar'],
                            "background-repeat: repeat-y;\n",
                            ["background-position: ", "0px ", (-offset_y).to_s, "px", ", ",
@@ -756,14 +759,14 @@ module Menu
                            ["padding-left: ", @sidebar_width.to_s, "px;\n"].join(''),
                            "}\n",
                            "\n",
-                           "GtkMenu :prelight {\n",
+                           "menu :hover {\n",
                            @__imagepath['foreground_with_sidebar'],
                            "background-repeat: repeat-y;\n",
                            "color: ",
                            "\#",
-                           sprintf("%02x", @__fontcolor['prelight'][0]),
-                           sprintf("%02x", @__fontcolor['prelight'][1]),
-                           sprintf("%02x", @__fontcolor['prelight'][2]),
+                           sprintf("%02x", @__fontcolor['hover'][0]),
+                           sprintf("%02x", @__fontcolor['hover'][1]),
+                           sprintf("%02x", @__fontcolor['hover'][2]),
                            ";\n",
                            ["background-position: ", "0px ", (-offset_y).to_s, "px", ", ",
                             @sidebar_width.to_s, "px", " ", (-offset_y).to_s, "px;\n"].join(''),
@@ -773,11 +776,10 @@ module Menu
       return false
     end
 
-    def on_tooltip(widget, x, y, keyboard_mode, tooltip, thumbnail)
-      if thumbnail == nil
+    def on_tooltip(widget, x, y, keyboard_mode, tooltip, pixbuf)
+      if pixbuf == nil
         return false
       end
-      pixbuf = Pix.create_pixbuf_from_file(thumbnail, :is_pnr => false)
       tooltip.set_icon(pixbuf)
       return true
     end
@@ -840,8 +842,9 @@ module Menu
       end
       if thumbnail != nil
         item.set_has_tooltip(true)
+        pixbuf = Pix.create_pixbuf_from_file(thumbnail, :is_pnr => false)
         item.signal_connect('query-tooltip') do |widget, x, y, keyboard_mode, tooltip|
-          next on_tooltip(widget, x, y, keyboard_mode, tooltip, thumbnail)
+          next on_tooltip(widget, x, y, keyboard_mode, tooltip, pixbuf)
         end
       else
         item.set_has_tooltip(false)
