@@ -96,9 +96,9 @@ module Seriko
       quality = @parent.handle_request('GET', 'get_preference', 'animation_quality')
       @fps = DEFAULT_FPS * quality
       if @prev_tick == 0 ## First time
-        delta_tick = 1000.0 / @fps # [msec]
+        delta_tick = (1000.0 / @fps) # [msec]
       else
-        delta_tick = (current_tick - @prev_tick) / 1000 # [msec]
+        delta_tick = ((current_tick - @prev_tick) / 1000) # [msec]
       end
       @next_tick += delta_tick
       @prev_tick = current_tick
@@ -116,7 +116,7 @@ module Seriko
     end
 
     def lock_exclusive(window, actor)
-      raise "assert" unless @exclusive_actor == nil
+      fail "assert" unless @exclusive_actor == nil
       terminate(window)
       @exclusive_actor = actor
       actor.set_post_proc(
@@ -126,7 +126,7 @@ module Seriko
     end
 
     def unlock_exclusive(window, actor)
-      raise "assert" unless @exclusive_actor == actor
+      fail "assert" unless @exclusive_actor == actor
       @exclusive_actor = nil
     end
 
@@ -367,7 +367,7 @@ module Seriko
     end
 
     def set_post_proc(post_proc, args)
-      raise "assert" unless @post_proc == nil
+      fail "assert" unless @post_proc == nil
       @post_proc = [post_proc, args]
     end
 
@@ -442,7 +442,7 @@ module Seriko
       elsif method == 'alternativestop'
         window.get_seriko.stop_actor(args.sample)
       else
-        raise RuntimeError('should not reach here')
+        fail RuntimeError('should not reach here')
       end
       @last_method = method
     end
@@ -664,9 +664,9 @@ module Seriko
         actor = Seriko::PassiveActor.new(actor_id, interval)
       end
       if version == 1
-        key = actor_id.to_s + 'option'
+        key = (actor_id.to_s + 'option')
       else
-        key = 'animation' + actor_id.to_s + '.option'
+        key = ('animation' + actor_id.to_s + '.option')
       end
       if config.include?(key) and config[key] == 'exclusive'
         actor.set_exclusive()
@@ -674,14 +674,14 @@ module Seriko
       begin
         for n in 0..127 # up to 128 patterns (0 - 127)
           if version == 1
-            key = actor_id.to_s + 'pattern' + n.to_s
+            key = (actor_id.to_s + 'pattern' + n.to_s)
           else
-            key = 'animation' + actor_id.to_s + '.pattern' + n.to_s
+            key = ('animation' + actor_id.to_s + '.pattern' + n.to_s)
           end
           if not config.include?(key)
-            key = actor_id.to_s + 'patturn' + n.to_s # only for version 1
+            key = (actor_id.to_s + 'patturn' + n.to_s) # only for version 1
             if not config.include?(key)
-              key = actor_id.to_s + 'putturn' + n.to_s # only for version 1
+              key = (actor_id.to_s + 'putturn' + n.to_s) # only for version 1
               if not config.include?(key)
                 next # XXX
               end
@@ -694,11 +694,11 @@ module Seriko
             match = re_seriko2_pattern.match(pattern)
           end
           if match == nil
-            raise ('unsupported pattern: ' + pattern)
+            fail ('unsupported pattern: ' + pattern)
           end
           if version == 1
             surface = match[1].to_i.to_s
-            interval = match[2].to_i.abs * 10
+            interval = (match[2].to_i.abs * 10)
             method = match[3]
           else
             method = match[1]
@@ -724,13 +724,13 @@ module Seriko
               group = match[4]
             end
             if group == nil
-              raise ('syntax error: ' + pattern)
+              fail ('syntax error: ' + pattern)
             end
             args = [group.to_i]
           elsif ['alternativestart', 'alternativestop'].include?(method)
             args = match[6]
             if args == nil
-              raise ('syntax error: ' + pattern)
+              fail ('syntax error: ' + pattern)
             end
             t = []
             for x in args[1, args.length - 2].split('.', 0)
@@ -827,17 +827,17 @@ module Seriko
     end
     mayuna = []
     for mayuna_id, interval in buf
-      ##raise "assert" unless interval == 'bind'
+      ##fail "assert" unless interval == 'bind'
       actor = Seriko::Mayuna.new(mayuna_id, interval)
       begin
         for n in 0..127 # up to 128 patterns (0 - 127)
           if version == 1
-            key = mayuna_id.to_s + 'pattern' + n.to_s
+            key = (mayuna_id.to_s + 'pattern' + n.to_s)
           else
-            key = 'animation' + mayuna_id.to_s + '.pattern' + n.to_s
+            key = ('animation' + mayuna_id.to_s + '.pattern' + n.to_s)
           end
           if not config.include?(key)
-            key = mayuna_id.to_s + 'patturn' + n.to_s # only for version 1
+            key = (mayuna_id.to_s + 'patturn' + n.to_s) # only for version 1
             if not config.include?(key)
               next # XXX
             end
@@ -849,11 +849,11 @@ module Seriko
             match = re_mayuna2_pattern.match(pattern)
           end
           if match == nil
-            raise ('unsupported pattern: ' + pattern)
+            fail ('unsupported pattern: ' + pattern)
           end
           if version == 1
             surface = match[1].to_i.to_s
-            interval = match[2].to_i.abs * 10
+            interval = (match[2].to_i.abs * 10)
             method = match[3]
           else
             method = match[1]
