@@ -39,7 +39,7 @@ module Ninix_Main
   bindtextdomain("ninix-aya")
 
   def self.handleException(exception)
-    message = "Uncaught exception (" + exception.class.to_s + ")\n" + exception.backtrace.join("\n")
+    message = ("Uncaught exception (" + exception.class.to_s + ")\n" + exception.backtrace.join("\n"))
     Logging::Logging.error(message)
     response_id = 1
     dialog = Gtk::MessageDialog.new(
@@ -79,7 +79,7 @@ module Ninix_Main
       end
     end
     dialog.destroy()
-    raise SystemExit
+    fail SystemExit
   end
   
   def self.main(option)
@@ -154,7 +154,7 @@ module Ninix_Main
     end
 
     def handle_request(event_type, event, *arglist)
-      raise "assert" unless ['GET', 'NOTIFY'].include?(event_type)
+      fail "assert" unless ['GET', 'NOTIFY'].include?(event_type)
       handlers = {
       }
       if not handlers.include?(event)
@@ -328,7 +328,7 @@ module Ninix_Main
     def handle_request(event_type, event, *arglist)
       return @parent.handle_request(event_type, event, *arglist)
     end
- 
+
     def create_menuitem(data)
       desc, balloon = data
       subdir = balloon['balloon_dir'][0]
@@ -455,7 +455,7 @@ module Ninix_Main
     end
 
     def handle_request(event_type, event, *arglist)
-      raise "assert" unless ['GET', 'NOTIFY'].include?(event_type)
+      fail "assert" unless ['GET', 'NOTIFY'].include?(event_type)
       handlers = {
         'close_all' => 'close_all_ghosts',
         'edit_preferences' => 'edit_preferences',
@@ -823,7 +823,7 @@ module Ninix_Main
     end
 
     def delete_ghost(key)
-      raise "assert" unless @ghosts.include?(key)
+      fail "assert" unless @ghosts.include?(key)
       @ghosts.delete(key)
     end
 
@@ -1122,15 +1122,15 @@ module Ninix_Main
 
     def start_sakura(key, prev: nil, vanished: false, init: false, temp: 0, abend: nil)
       sakura = @ghosts[key].instance
-      raise "assert" unless sakura != nil
+      fail "assert" unless sakura != nil
       if prev != nil
-        raise "assert" unless @ghosts.include?(prev) ## FIXME: vanish case?
-        raise "assert" unless @ghosts[prev].instance != nil
+        fail "assert" unless @ghosts.include?(prev) ## FIXME: vanish case?
+        fail "assert" unless @ghosts[prev].instance != nil
       end
       if init
         ghost_changed = false
       else
-        raise "assert" unless prev != nil ## FIXME
+        fail "assert" unless prev != nil ## FIXME
         if prev == key
           ghost_changed = false
         else
@@ -1643,7 +1643,7 @@ module Ninix_Main
       ai_list = @items[0][2]
       if not ai_list.empty?
         path = ai_list.sample
-        raise "assert" unless File.exists?(path)
+        fail "assert" unless File.exists?(path)
         @pixbuf = Pix.create_pixbuf_from_file(path, :is_pnr => false)
         @pixbuf.saturate_and_pixelate(1.0, true)
       else
@@ -1711,36 +1711,36 @@ module Ninix_Main
                  time, time_w, time_h]
       end
       w1 = 280
-      w2 = w - w1 - w3 - w4 - 70
+      w2 = (w - w1 - w3 - w4 - 70)
       x = 20
       y = 15
-      x += w1 + 10
+      x += (w1 + 10)
       label = 'name'
       layout.set_text(label)
       label_name_w, label_name_h = layout.pixel_size
       cr.set_source_rgb(0.8, 0.8, 0.8) # gray
       cr.move_to(x, y)
       cr.show_pango_layout(layout)
-      x = x + w2 + 10
+      x = (x + w2 + 10)
       label = 'rate'
       layout.set_text(label)
       label_rate_w, label_rate_h = layout.pixel_size
       cr.set_source_rgb(0.8, 0.8, 0.8) # gray
       cr.move_to(x + w3 - label_rate_w, y)
       cr.show_pango_layout(layout)
-      x += w3 + 10
+      x += (w3 + 10)
       label = 'time'
       layout.set_text(label)
       label_time_w, label_time_h = layout.pixel_size
       cr.set_source_rgb(0.8, 0.8, 0.8) # gray
       cr.move_to(x + w4 - label_time_w, y)
       cr.show_pango_layout(layout)
-      y += [label_name_h, label_rate_h, label_time_h].max + 4
+      y += ([label_name_h, label_rate_h, label_time_h].max + 4)
       for clock, name, name_w, name_h, rate, rate_w, rate_h, time, time_w, \
           time_h in rows
         x = 20
         bw = (clock / total * w1).to_i
-        bh = [name_h, rate_h, time_h].max - 1
+        bh = ([name_h, rate_h, time_h].max - 1)
         cr.set_source_rgb(0.8, 0.8, 0.8) # gray
         cr.rectangle(x + 1, y + 1, bw, bh)
         cr.stroke()
@@ -1750,7 +1750,7 @@ module Ninix_Main
         cr.set_source_rgb(0.0, 0.0, 0.0) # black
         cr.rectangle(x, y, bw, bh)
         cr.stroke()
-        x += w1 + 10
+        x += (w1 + 10)
         layout.set_text(name)
         end_ = name.length
         while end_ > 0
@@ -1765,17 +1765,17 @@ module Ninix_Main
         cr.set_source_rgb(0.0, 0.0, 0.0) # black
         cr.move_to(x, y)
         cr.show_pango_layout(layout)
-        x += w2 + 10
+        x += (w2 + 10)
         layout.set_text(rate)
         cr.set_source_rgb(0.0, 0.0, 0.0) # black
         cr.move_to(x + w3 - rate_w, y)
         cr.show_pango_layout(layout)
-        x += w3 + 10
+        x += (w3 + 10)
         layout.set_text(time)
         cr.set_source_rgb(0.0, 0.0, 0.0) # black
         cr.move_to(x + w4 - time_w, y)
         cr.show_pango_layout(layout)
-        y += [name_h, rate_h, time_h].max + 4
+        y += ([name_h, rate_h, time_h].max + 4)
       end
     end
   end
